@@ -274,13 +274,20 @@ static void *get_dlsym(const char *symname, const char *symver)
 void __attribute__ ((destructor)) libsb_fini(void)
 {
 	int x;
+
+	sb_init = 0;
+	
 	if(NULL != cached_env_vars) {
 		for(x=0; x < 4; x++) {
-			if(NULL != cached_env_vars[x])
+			if(NULL != cached_env_vars[x]) {
 				free(cached_env_vars[x]);
+				cached_env_vars[x] = NULL;
+			}
 		}
 		free(cached_env_vars);
+		cached_env_vars = NULL;
 	}
+	
 	clean_env_entries(&(sbcontext.deny_prefixes),
 			&(sbcontext.num_deny_prefixes));
 	clean_env_entries(&(sbcontext.read_prefixes),
@@ -1088,7 +1095,8 @@ static int check_access(sbcontext_t * sbcontext, const char *func, const char *p
 		 * of the symlink's parent also have write access. */
 		if (((0 == strncmp(func, "unlink", 6)) ||
 		     (0 == strncmp(func, "lchown", 6)) ||
-		     (0 == strncmp(func, "rename", 6))) &&
+		     (0 == strncmp(func, "rename", 6)) ||
+		     (0 == strncmp(func, "symlink", 7))) &&
 		    ((-1 != lstat(path, &st)) && (S_ISLNK(st.st_mode)))) {
 			/* Check if the symlink unresolved path have access */
 			retval = check_prefixes(sbcontext->write_prefixes,
@@ -1327,14 +1335,14 @@ static int before_syscall(const char *func, const char *file)
 		return 0;
 	}
 
-	if(sb_init == 0) {
+	if(0 == sb_init) {
 		init_context(&sbcontext);
-		cached_env_vars = malloc(sizeof(char *)*4);
+		cached_env_vars = malloc(sizeof(char *) * 4);
 		cached_env_vars[0] = cached_env_vars[1] = cached_env_vars[2] = cached_env_vars[3] = NULL;
-		sb_init=1;
+		sb_init = 1;
 	}
 
-	if((deny == NULL && cached_env_vars[0] != deny) || cached_env_vars[0] == NULL ||
+	if((NULL == deny && cached_env_vars[0] != deny) || NULL == cached_env_vars[0] ||
 		strcmp(cached_env_vars[0], deny) != 0) {
 
 		clean_env_entries(&(sbcontext.deny_prefixes),
@@ -1352,7 +1360,7 @@ static int before_syscall(const char *func, const char *file)
 		}
 	}
 
-	if((read == NULL && cached_env_vars[1] != read) || cached_env_vars[1] == NULL || 
+	if((NULL == read && cached_env_vars[1] != read) || NULL == cached_env_vars[1] || 
 		strcmp(cached_env_vars[1], read) != 0) {
 
 		clean_env_entries(&(sbcontext.read_prefixes),
@@ -1370,7 +1378,7 @@ static int before_syscall(const char *func, const char *file)
 		}
 	}
 
-	if((write == NULL && cached_env_vars[2] != write) || cached_env_vars[2] == NULL ||
+	if((NULL == write && cached_env_vars[2] != write) || NULL == cached_env_vars[2] ||
 		strcmp(cached_env_vars[2], write) != 0) {
 
 		clean_env_entries(&(sbcontext.write_prefixes),
@@ -1388,7 +1396,7 @@ static int before_syscall(const char *func, const char *file)
 		}
 	}
 
-	if((predict == NULL && cached_env_vars[3] != predict) || cached_env_vars[3] == NULL ||
+	if((NULL == predict && cached_env_vars[3] != predict) || NULL == cached_env_vars[3] ||
 		strcmp(cached_env_vars[3], predict) != 0) {
 
 		clean_env_entries(&(sbcontext.predict_prefixes),
@@ -1441,7 +1449,7 @@ static int before_syscall_open_int(const char *func, const char *file, int flags
 
 static int before_syscall_open_char(const char *func, const char *file, const char *mode)
 {
-	if (*mode == 'r' && ((strcmp(mode, "r") == 0) ||
+	if (*mode == 'r' && (0 == (strcmp(mode, "r")) ||
 	    /* The strspn accept args are known non-writable modifiers */
 	    (strlen(++mode) == strspn(mode, "xbtmc")))) {
 		return before_syscall("open_rd", file);
